@@ -1,7 +1,7 @@
 /*
  * answer.c -- manipulating query answers and encoding them.
  *
- * Copyright (c) 2001-2011, NLnet Labs. All rights reserved.
+ * Copyright (c) 2001-2006, NLnet Labs. All rights reserved.
  *
  * See LICENSE for the license.
  *
@@ -34,7 +34,7 @@ answer_add_rrset(answer_type *answer, rr_section_type section,
 	/* Don't add an RRset multiple times.  */
 	for (i = 0; i < answer->rrset_count; ++i) {
 		if (answer->rrsets[i] == rrset &&
-			answer->domains[i] == domain) {
+			answer->domains[i]->number == domain->number) {
 			if (section < answer->section[i]) {
 				answer->section[i] = section;
 				return 1;
@@ -67,7 +67,7 @@ encode_answer(query_type *q, const answer_type *answer)
 	int done = 0;
 
 #if defined(INET6) && defined(MINIMAL_RESPONSES)
-	if (q->addr.ss_family == AF_INET6)
+	if (q->client_addr.ss_family == AF_INET6)
 		minimal_respsize = IPV6_MINIMAL_RESPONSE_SIZE;
 #endif
 
@@ -95,6 +95,11 @@ encode_answer(query_type *q, const answer_type *answer)
 		 * sections.
 		 */
 		if (done) {
+			/* delegations should have a usable address in it */
+			if(section == ADDITIONAL_A_SECTION &&
+				counts[ADDITIONAL_A_SECTION] == 0 &&
+				q->delegation_domain)
+				TC_SET(q->packet);
 			break;
 		}
 #endif
