@@ -392,6 +392,12 @@ const char *
 dname_to_string(const dname_type *dname, const dname_type *origin)
 {
 	static char buf[MAXDOMAINLEN * 5];
+	return dname_to_string_buf(dname, origin, buf);
+}
+
+const char *
+dname_to_string_buf(const dname_type *dname, const dname_type *origin, char buf[MAXDOMAINLEN * 5])
+{
 	size_t i;
 	size_t labels_to_convert = dname->label_count - 1;
 	int absolute = 1;
@@ -399,7 +405,7 @@ dname_to_string(const dname_type *dname, const dname_type *origin)
 	const uint8_t *src;
 
 	if (dname->label_count == 1) {
-		strlcpy(buf, ".", sizeof(buf));
+		strlcpy(buf, ".", MAXDOMAINLEN * 5);
 		return buf;
 	}
 
@@ -579,3 +585,32 @@ int dname_equal_nocase(uint8_t* a, uint8_t* b, uint16_t len)
 	}
 	return 1;
 }
+
+int
+is_dname_subdomain_of_case(const uint8_t* d, unsigned int len,
+	const uint8_t* d2, unsigned int len2)
+{
+	unsigned int i;
+	if(len < len2)
+		return 0;
+	if(len == len2) {
+		if(memcmp(d, d2, len) == 0)
+			return 1;
+		return 0;
+	}
+	/* so len > len2, for d=a.example.com. and d2=example.com. */
+	/* trailing portion must be exactly name d2. */
+	if(memcmp(d+len-len2, d2, len2) != 0)
+		return 0;
+	/* that must also be a label point */
+	i=0;
+	while(i < len) {
+		if(i == len-len2)
+			return 1;
+		i += d[i];
+		i += 1;
+	}
+
+	/* The trailing portion is not at a label point. */
+	return 0;
+}
