@@ -724,27 +724,32 @@ writepid(struct nsd *nsd)
 	}
 	close(fd);
 
-	if (chown(nsd->pidfile, nsd->uid, nsd->gid) == -1) {
-		log_msg(LOG_ERR, "cannot chown %u.%u %s: %s",
-			(unsigned) nsd->uid, (unsigned) nsd->gid,
-			nsd->pidfile, strerror(errno));
-		return -1;
-	}
-
 	return 0;
 }
 
 void
-unlinkpid(const char* file)
+unlinkpid(const char* file, const char* username)
 {
 	int fd = -1;
 
 	if (file && file[0]) {
 		/* truncate pidfile */
-		fd = open(file, O_WRONLY | O_TRUNC, 0644);
+		fd = open(file, O_WRONLY | O_TRUNC
+#ifdef O_NOFOLLOW
+			| O_NOFOLLOW
+#endif
+			, 0644);
 		if (fd == -1) {
 			/* Truncate the pid file.  */
-			log_msg(LOG_ERR, "can not truncate the pid file %s: %s", file, strerror(errno));
+			/* If there is a username configured, we assume that
+			 * due to privilege drops, NSD cannot truncate or
+			 * unlink the pid file. NSD does not chown the file
+			 * because that creates a privilege escape. */
+			if(username && username[0]) {
+				VERBOSITY(5, (LOG_INFO, "can not truncate the pid file %s: %s", file, strerror(errno)));
+			} else {
+				log_msg(LOG_ERR, "can not truncate the pid file %s: %s", file, strerror(errno));
+			}
 		} else {
 			close(fd);
 		}
@@ -754,9 +759,15 @@ unlinkpid(const char* file)
 			/* this unlink may not work if the pidfile is located
 			 * outside of the chroot/workdir or we no longer
 			 * have permissions */
-			VERBOSITY(3, (LOG_WARNING,
-				"failed to unlink pidfile %s: %s",
-				file, strerror(errno)));
+			if(username && username[0]) {
+				VERBOSITY(5, (LOG_INFO,
+					"failed to unlink pidfile %s: %s",
+					file, strerror(errno)));
+			} else {
+				VERBOSITY(3, (LOG_WARNING,
+					"failed to unlink pidfile %s: %s",
+					file, strerror(errno)));
+			}
 		}
 	}
 }
@@ -1194,6 +1205,7 @@ main(int argc, char *argv[])
 	nsd.ipv6_edns_size = nsd.options->ipv6_edns_size;
 #ifdef HAVE_SSL
 	nsd.tls_ctx = NULL;
+	nsd.tls_auth_ctx = NULL;
 #endif
 
 	if(udp_port == 0)
@@ -1486,7 +1498,14 @@ main(int argc, char *argv[])
 	log_msg(LOG_NOTICE, "%s starting (%s)", argv0, PACKAGE_STRING);
 
 	/* Do we have a running nsd? */
-	if(nsd.pidfile && nsd.pidfile[0]) {
+	/* When there is a username configured, we assume that due to
+	 * privilege drops, the pidfile could not be removed by NSD and
+	 * as such could be lingering around. We could not remove it,
+	 * and also not chown it as that creates privilege escape problems.
+	 * The init system could remove the pidfile after use for us, but
+	 * it is not sure if it is configured to do so. */
+	if(nsd.pidfile && nsd.pidfile[0] &&
+		!(nsd.username && nsd.username[0])) {
 		if ((oldpid = readpid(nsd.pidfile)) == -1) {
 			if (errno != ENOENT) {
 				log_msg(LOG_ERR, "can't read pidfile %s: %s",
@@ -1559,9 +1578,17 @@ main(int argc, char *argv[])
 #if defined(HAVE_SSL)
 	if(nsd.options->tls_service_key && nsd.options->tls_service_key[0]
 	   && nsd.options->tls_service_pem && nsd.options->tls_service_pem[0]) {
+		/* normal tls port with no client authentication */
 		if(!(nsd.tls_ctx = server_tls_ctx_create(&nsd, NULL,
-			nsd.options->tls_service_ocsp)))
+		     nsd.options->tls_service_ocsp)))
 			error("could not set up tls SSL_CTX");
+		/* tls-auth port with required client authentication */
+		if(nsd.options->tls_auth_port) {
+			if(!(nsd.tls_auth_ctx = server_tls_ctx_create(&nsd,
+			     (char*)nsd.options->tls_cert_bundle,
+			     nsd.options->tls_service_ocsp)))
+				error("could not set up tls SSL_CTX");
+		}
 	}
 #endif /* HAVE_SSL */
 
@@ -1740,7 +1767,7 @@ main(int argc, char *argv[])
 #endif /* USE_DNSTAP */
 	}
 	if (server_prepare(&nsd) != 0) {
-		unlinkpid(nsd.pidfile);
+		unlinkpid(nsd.pidfile, nsd.username);
 		error("server preparation failed, %s could "
 			"not be started", argv0);
 	}
