@@ -63,6 +63,14 @@ static log_function_type *current_log_function = log_file;
 static FILE *current_log_file = NULL;
 int log_time_asc = 1;
 
+#ifdef USE_LOG_PROCESS_ROLE
+void
+log_set_process_role(const char *process_role)
+{
+	global_ident = process_role;
+}
+#endif
+
 void
 log_init(const char *ident)
 {
@@ -500,113 +508,6 @@ timespec_subtract(struct timespec *left,
 	}
 }
 
-uint32_t
-strtoserial(const char* nptr, const char** endptr)
-{
-	uint32_t i = 0;
-	uint32_t serial = 0;
-
-	for(*endptr = nptr; **endptr; (*endptr)++) {
-		switch (**endptr) {
-		case ' ':
-		case '\t':
-			break;
-		case '0':
-		case '1':
-		case '2':
-		case '3':
-		case '4':
-		case '5':
-		case '6':
-		case '7':
-		case '8':
-		case '9':
-			if((i*10)/10 != i)
-				/* number too large, return i
-				 * with *endptr != 0 as a failure*/
-				return i;
-			i *= 10;
-			i += (**endptr - '0');
-			break;
-		default:
-			break;
-		}
-	}
-	serial += i;
-	return serial;
-}
-
-uint32_t
-strtottl(const char *nptr, const char **endptr)
-{
-	uint32_t i = 0;
-	uint32_t seconds = 0;
-
-	for(*endptr = nptr; **endptr; (*endptr)++) {
-		switch (**endptr) {
-		case ' ':
-		case '\t':
-			break;
-		case 's':
-		case 'S':
-			seconds += i;
-			i = 0;
-			break;
-		case 'm':
-		case 'M':
-			seconds += i * 60;
-			i = 0;
-			break;
-		case 'h':
-		case 'H':
-			seconds += i * 60 * 60;
-			i = 0;
-			break;
-		case 'd':
-		case 'D':
-			seconds += i * 60 * 60 * 24;
-			i = 0;
-			break;
-		case 'w':
-		case 'W':
-			seconds += i * 60 * 60 * 24 * 7;
-			i = 0;
-			break;
-		case '0':
-		case '1':
-		case '2':
-		case '3':
-		case '4':
-		case '5':
-		case '6':
-		case '7':
-		case '8':
-		case '9':
-			i *= 10;
-			i += (**endptr - '0');
-			break;
-		default:
-			seconds += i;
-			/**
-			 * According to RFC2308, Section 8, the MSB
-			 * (sign bit) should be set to zero.
-			 * If we encounter a value larger than 2^31 -1,
-			 * we fall back to the default TTL.
-			 */
-			if ((seconds & MSB_32)) {
-				seconds = DEFAULT_TTL;
-			}
-			return seconds;
-		}
-	}
-	seconds += i;
-	if ((seconds & MSB_32)) {
-		seconds = DEFAULT_TTL;
-	}
-	return seconds;
-}
-
-
 ssize_t
 hex_ntop(uint8_t const *src, size_t srclength, char *target, size_t targsize)
 {
@@ -814,53 +715,6 @@ hexdigit_to_int(char ch)
 	}
 }
 
-/* Number of days per month (except for February in leap years). */
-static const int mdays[] = {
-    31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31
-};
-
-static int
-is_leap_year(int year)
-{
-    return year % 4 == 0 && (year % 100 != 0 || year % 400 == 0);
-}
-
-static int
-leap_days(int y1, int y2)
-{
-    --y1;
-    --y2;
-    return (y2/4 - y1/4) - (y2/100 - y1/100) + (y2/400 - y1/400);
-}
-
-/*
- * Code adapted from Python 2.4.1 sources (Lib/calendar.py).
- */
-time_t
-mktime_from_utc(const struct tm *tm)
-{
-    int year = 1900 + tm->tm_year;
-    time_t days = 365 * (year - 1970) + leap_days(1970, year);
-    time_t hours;
-    time_t minutes;
-    time_t seconds;
-    int i;
-
-    for (i = 0; i < tm->tm_mon; ++i) {
-        days += mdays[i];
-    }
-    if (tm->tm_mon > 1 && is_leap_year(year)) {
-        ++days;
-    }
-    days += tm->tm_mday - 1;
-
-    hours = days * 24 + tm->tm_hour;
-    minutes = hours * 60 + tm->tm_min;
-    seconds = minutes * 60 + tm->tm_sec;
-
-    return seconds;
-}
-
 /* code to calculate CRC. Lifted from BSD 4.4 crc.c in cksum(1). BSD license.
    http://www.tsfr.org/~orc/Code/bsd/bsd-current/cksum/crc.c.
    or http://gobsd.com/code/freebsd/usr.bin/cksum/crc.c
@@ -1215,7 +1069,7 @@ int number_of_cpus(void)
  * with a linker error, we print an error when it is used */
 int set_cpu_affinity(cpuset_t *ATTR_UNUSED(set))
 {
-	log_err("sched_setaffinity: not available on this system");
+	log_msg(LOG_ERR, "sched_setaffinity: not available on this system");
 	return -1;
 }
 #elif defined(HAVE_SCHED_SETAFFINITY)
