@@ -43,6 +43,15 @@ struct nsd;
  */
 void log_init(const char *ident);
 
+#ifdef USE_LOG_PROCESS_ROLE
+/*
+ * Set the name of the role for the process (for debugging purposes)
+ */
+void log_set_process_role(const char* role);
+#else
+#define log_set_process_role(role) /* empty */
+#endif
+
 /*
  * Open the system log.  If FILENAME is not NULL, a log file is opened
  * as well.
@@ -312,25 +321,6 @@ timeval_to_timespec(struct timespec *left,
 /* get the time */
 void get_time(struct timespec* t);
 
-/*
- * Converts a string representation of a period of time into
- * a long integer of seconds or serial value.
- *
- * Set the endptr to the first illegal character.
- *
- * Interface is similar as strtol(3)
- *
- * Returns:
- *	LONG_MIN if underflow occurs
- *	LONG_MAX if overflow occurs.
- *	otherwise number of seconds
- *
- * XXX These functions do not check the range.
- *
- */
-uint32_t strtoserial(const char *nptr, const char **endptr);
-uint32_t strtottl(const char *nptr, const char **endptr);
-
 /*
  * Convert binary data to a string of hexadecimal characters.
  */
@@ -356,12 +346,6 @@ void strip_string(char *str);
  */
 int hexdigit_to_int(char ch);
 
-/*
- * Convert TM to seconds since epoch (midnight, January 1st, 1970).
- * Like timegm(3), which is not always available.
- */
-time_t mktime_from_utc(const struct tm *tm);
-
 /*
  * Add bytes to given crc. Returns new CRC sum.
  * Start crc val with 0xffffffff on first call. XOR crc with
