@@ -274,18 +274,20 @@ xfrd_handle_notify_reply(struct notify_zone* zone, buffer_type* packet,
 static int
 xfrd_notify_send_udp(struct notify_zone* zone, int index)
 {
+	int apex_compress = 0;
 	buffer_type* packet = xfrd_get_temp_buffer();
 	if(!zone->pkts[index].dest) return 0;
 	/* send NOTIFY to secondary. */
 	xfrd_setup_packet(packet, TYPE_SOA, CLASS_IN, zone->apex,
-		qid_generate());
+		qid_generate(), &apex_compress);
 	zone->pkts[index].notify_query_id = ID(packet);
 	OPCODE_SET(packet, OPCODE_NOTIFY);
 	AA_SET(packet);
 	if(zone->current_soa->serial != 0) {
 		/* add current SOA to answer section */
 		ANCOUNT_SET(packet, 1);
-		xfrd_write_soa_buffer(packet, zone->apex, zone->current_soa);
+		xfrd_write_soa_buffer(packet, zone->apex, zone->current_soa,
+			apex_compress);
 	}
 	if(zone->pkts[index].dest->key_options) {
 		xfrd_tsig_sign_request(packet, &zone->notify_tsig, zone->pkts[index].dest);
@@ -382,6 +384,8 @@ notify_setup_event(struct notify_zone* zone)
 			event_del(&zone->notify_send_handler);
 		}
 		zone->notify_timeout.tv_sec = XFRD_NOTIFY_RETRY_TIMOUT;
+		memset(&zone->notify_send_handler, 0,
+			sizeof(zone->notify_send_handler));
 		event_set(&zone->notify_send_handler, fd, EV_READ | EV_TIMEOUT,
 			xfrd_handle_notify_send, zone);
 		if(event_base_set(xfrd->event_base, &zone->notify_send_handler) != 0)
@@ -396,6 +400,8 @@ notify_setup_event(struct notify_zone* zone)
 			event_del(&zone->notify_send6_handler);
 		}
 		zone->notify_timeout.tv_sec = XFRD_NOTIFY_RETRY_TIMOUT;
+		memset(&zone->notify_send6_handler, 0,
+			sizeof(zone->notify_send6_handler));
 		event_set(&zone->notify_send6_handler, fd, EV_READ | EV_TIMEOUT,
 			xfrd_handle_notify_send, zone);
 		if(event_base_set(xfrd->event_base, &zone->notify_send6_handler) != 0)
@@ -465,6 +471,8 @@ setup_notify_active(struct notify_zone* zone)
 
 	if(zone->notify_send_enable)
 		notify_send_disable(zone);
+	memset(&zone->notify_send_handler, 0,
+		sizeof(zone->notify_send_handler));
 	event_set(&zone->notify_send_handler, -1, EV_TIMEOUT,
 		xfrd_handle_notify_send, zone);
 	if(event_base_set(xfrd->event_base, &zone->notify_send_handler) != 0)
